@@ -35,6 +35,7 @@ from gbp.scripts.common import ExitCodes
 from gbp.scripts.common.import_orig import (orig_needs_repack, cleanup_tmp_tree,
                                             ask_package_name, ask_package_version,
                                             repack_source, is_link_target, download_orig)
+from gbp.scripts.common.hook import Hook
 
 
 class RollbackError(GitRepositoryError):
@@ -49,6 +50,7 @@ class RollbackError(GitRepositoryError):
     def __str__(self):
         return "%s %s" % (self.msg, self.errors)
 
+
 class ImportOrigDebianGitRepository(DebianGitRepository):
     """
     Like a DebianGitRepository but can also perform rollbacks and knows
@@ -323,7 +325,9 @@ def debian_branch_merge(repo, tag, version, options):
                'GBP_UPSTREAM_VERSION': version,
                'GBP_DEBIAN_VERSION': debian_version,
                }
-        gbpc.Command(format_str(options.postimport, info), extra_env=env, shell=True)()
+        Hook('Postimport',
+             format_str(options.postimport, info),
+             extra_env=env)()
 
 
 def debian_branch_merge_by_replace(repo, tag, version, options):
@@ -400,48 +404,47 @@ def build_parser(name):
         return None
 
     import_group = GbpOptionGroup(parser, "import options",
-                      "pristine-tar and filtering")
+                                  "pristine-tar and filtering")
     tag_group = GbpOptionGroup(parser, "tag options",
-                      "options related to git tag creation")
+                               "options related to git tag creation")
     branch_group = GbpOptionGroup(parser, "version and branch naming options",
-                      "version number and branch layout options")
-    cmd_group = GbpOptionGroup(parser, "external command options", "how and when to invoke external commands and hooks")
-
-    for group in [import_group, branch_group, tag_group, cmd_group ]:
+                                  "version number and branch layout options")
+    cmd_group = GbpOptionGroup(parser, "external command options",
+                               "how and when to invoke external commands and hooks")
+    for group in [import_group, branch_group, tag_group, cmd_group]:
         parser.add_option_group(group)
 
     branch_group.add_option("-u", "--upstream-version", dest="version",
-                      help="Upstream Version")
+                            help="Upstream Version")
     branch_group.add_config_file_option(option_name="debian-branch",
-                      dest="debian_branch")
+                                        dest="debian_branch")
     branch_group.add_config_file_option(option_name="upstream-branch",
-                      dest="upstream_branch")
+                                        dest="upstream_branch")
     branch_group.add_config_file_option(option_name="upstream-vcs-tag", dest="vcs_tag",
-                            help="Upstream VCS tag add to the merge commit")
+                                        help="Upstream VCS tag add to the merge commit")
     branch_group.add_boolean_config_file_option(option_name="merge", dest="merge")
     branch_group.add_config_file_option(option_name="merge-mode", dest="merge_mode")
 
     tag_group.add_boolean_config_file_option(option_name="sign-tags",
-                      dest="sign_tags")
+                                             dest="sign_tags")
     tag_group.add_config_file_option(option_name="keyid",
-                      dest="keyid")
+                                     dest="keyid")
     tag_group.add_config_file_option(option_name="upstream-tag",
-                      dest="upstream_tag")
+                                     dest="upstream_tag")
     import_group.add_config_file_option(option_name="filter",
-                      dest="filters", action="append")
+                                        dest="filters", action="append")
     import_group.add_boolean_config_file_option(option_name="pristine-tar",
-                      dest="pristine_tar")
+                                                dest="pristine_tar")
     import_group.add_boolean_config_file_option(option_name="filter-pristine-tar",
-                      dest="filter_pristine_tar")
+                                                dest="filter_pristine_tar")
     import_group.add_config_file_option(option_name="import-msg",
-                      dest="import_msg")
+                                        dest="import_msg")
     import_group.add_boolean_config_file_option(option_name="symlink-orig",
                                                 dest="symlink_orig")
     import_group.add_config_file_option("component", action="append", metavar='COMPONENT',
                                         dest="components")
     cmd_group.add_config_file_option(option_name="postimport", dest="postimport")
 
-
     parser.add_boolean_config_file_option(option_name="interactive",
                                           dest='interactive')
     parser.add_boolean_config_file_option(option_name="rollback",
@@ -644,6 +647,7 @@ def main(argv):
         gbp.log.info("Successfully imported version %s of %s" % (version, source.path))
     return ret
 
+
 if __name__ == "__main__":
     sys.exit(main(sys.argv))
 
