@@ -50,7 +50,6 @@ cl_debian = """test-package (0.9-1) unstable; urgency=%s
 class TestScriptDch(DebianGitTestRepo):
     """Test git-dch"""
 
-
     def setUp(self):
         DebianGitTestRepo.setUp(self)
         self.add_file("foo", "bar")
@@ -70,11 +69,9 @@ class TestScriptDch(DebianGitTestRepo):
                         "--upstream-branch=upstream", "--id-length=0", "--spawn-editor=/bin/true"]
         self.repo.create_tag(deb_tag, msg=deb_tag_msg, commit="HEAD~1")
 
-
     def tearDown(self):
         DebianGitTestRepo.tearDown(self)
 
-
     def run_dch(self, dch_options=None):
         # Take care to copy the list
         options = self.options[:]
@@ -84,14 +81,12 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertEqual(ret, 0)
         return open("debian/changelog").readlines()
 
-
     def test_dch_main_new_upstream_version(self):
         """Test dch.py like gbp dch script does: new upstream version"""
         lines = self.run_dch()
         self.assertEqual("test-package (1.0-1) UNRELEASED; urgency=%s\n" % default_urgency, lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_release(self):
         """Test dch.py like gbp dch script does: new upstream version - release"""
         options = ["--release"]
@@ -99,7 +94,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertEqual("test-package (1.0-1) %s; urgency=%s\n" % (os_codename, default_urgency), lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_auto(self):
         """Test dch.py like gbp dch script does: new upstream version - guess last commit"""
         options = ["--auto"]
@@ -107,7 +101,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertEqual("test-package (1.0-1) UNRELEASED; urgency=%s\n" % default_urgency, lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_snapshot(self):
         """Test dch.py like gbp dch script does: new upstream version - snapshot mode"""
         options = ["--snapshot"]
@@ -118,7 +111,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertIsNotNone(re.search(snap_mark + header.group(1), lines[2]))
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_2_snapshots_auto(self):
         """Test dch.py like gbp dch script does: new upstream version - two snapshots - auto"""
         options = ["--snapshot"]
@@ -141,7 +133,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertIn("""  * added debian/control\n""", lines)
         self.assertIn("""  * added debian/compat\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_2_snapshots_commit_auto(self):
         """Test dch.py like gbp dch script does: new upstream version - two committed snapshots - auto"""
         options = ["--commit"]
@@ -168,7 +159,6 @@ class TestScriptDch(DebianGitTestRepo):
         # But its changelog must be included in the new one
         self.assertIn("""  * TEST-COMMITTED-SNAPSHOT\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_auto_release(self):
         """Test dch.py like gbp dch script does: new upstream version - auto - release"""
         options = ["--auto", "--release"]
@@ -176,10 +166,9 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertEqual("test-package (1.0-1) %s; urgency=%s\n" % (os_codename, default_urgency), lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_auto_snapshot(self):
         """Test dch.py like gbp dch script does: new upstream version - auto - snapshot mode"""
-        options = [ "--auto", "--snapshot" ]
+        options = ["--auto", "--snapshot"]
         options.append("--snapshot")
         lines = self.run_dch(options)
         header = re.search(snap_header_1, lines[0])
@@ -188,7 +177,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertIsNotNone(re.search(snap_mark + header.group(1), lines[2]))
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_snapshot_release(self):
         """Test dch.py like gbp dch script does: new upstream version - snapshot - release"""
         options = ["--snapshot", "--release"]
@@ -196,7 +184,6 @@ class TestScriptDch(DebianGitTestRepo):
             self.assertRaises(SystemExit, self.run_dch, options)
         self.assertTrue("'--snapshot' and '--release' are incompatible options" in c.output())
 
-
     def test_dch_main_new_upstream_version_with_distribution(self):
         """Test dch.py like gbp dch script does: new upstream version - set distribution"""
         options = ["--distribution=testing", "--force-distribution"]
@@ -204,7 +191,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertEqual("test-package (1.0-1) testing; urgency=%s\n" % default_urgency, lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_release_distribution(self):
         """Test dch.py like gbp dch script does: new upstream version - release - set distribution"""
         options = ["--release", "--distribution=testing", "--force-distribution"]
@@ -212,7 +198,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertEqual("test-package (1.0-1) testing; urgency=%s\n" % default_urgency, lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_snapshot_distribution(self):
         """Test dch.py like gbp dch script does: new upstream version - snapshot mode - do not set distribution"""
         options = ["--snapshot", "--distribution=testing"]
@@ -223,7 +208,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertIsNotNone(re.search(snap_mark + header.group(1), lines[2]))
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_2_snapshots_auto_distribution(self):
         """Test dch.py like gbp dch script does: new upstream version - two snapshots - do not set distribution"""
         options = ["--snapshot", "--distribution=testing"]
@@ -249,7 +233,6 @@ class TestScriptDch(DebianGitTestRepo):
         # we do not commit
         self.assertNotIn("""  * TEST-COMMITTED-SNAPSHOT\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_2_snapshots_commit_auto_distribution(self):
         """Test dch.py like gbp dch script does: new upstream version - two committed snapshots - do not set distribution"""
         options = ["--commit"]
@@ -277,7 +260,6 @@ class TestScriptDch(DebianGitTestRepo):
         # But its changelog must be included in the new one
         self.assertIn("""  * TEST-COMMITTED-SNAPSHOT\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_urgency(self):
         """Test dch.py like gbp dch script does: new upstream version - set urgency"""
         options = ["--urgency=emergency"]
@@ -285,7 +267,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertEqual("test-package (1.0-1) UNRELEASED; urgency=emergency\n", lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_release_urgency(self):
         """Test dch.py like gbp dch script does: new upstream version - release - set urgency"""
         options = ["--release", "--urgency=emergency"]
@@ -293,10 +274,9 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertEqual("test-package (1.0-1) %s; urgency=emergency\n" % os_codename, lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_new_upstream_version_with_snapshot_urgency(self):
         """Test dch.py like gbp dch script does: new upstream version - snapshot mode - set urgency"""
-        options = ["--snapshot",  "--urgency=emergency"]
+        options = ["--snapshot", "--urgency=emergency"]
         lines = self.run_dch(options)
         header = re.search(snap_header_1, lines[0])
         self.assertIsNotNone(header)
@@ -304,7 +284,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertIsNotNone(re.search(snap_mark + header.group(1), lines[2]))
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_increment_debian_version(self):
         """Test dch.py like gbp dch script does: increment debian version"""
         self.repo.delete_tag("debian/0.9-1")
@@ -314,7 +293,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertEqual("test-package (%s) UNRELEASED; urgency=%s\n" % (new_version_0_9, default_urgency), lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_increment_debian_version_with_release(self):
         """Test dch.py like gbp dch script does: increment debian version - release"""
         self.repo.delete_tag("upstream/1.0")
@@ -323,7 +301,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertEqual("test-package (%s) %s; urgency=%s\n" % (new_version_0_9, os_codename, default_urgency), lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_increment_debian_version_with_auto(self):
         """Test dch.py like gbp dch script does: increment debian version - guess last commit"""
         self.repo.delete_tag("upstream/1.0")
@@ -332,7 +309,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertEqual("test-package (%s) UNRELEASED; urgency=%s\n" % (new_version_0_9, default_urgency), lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_increment_debian_version_with_snapshot(self):
         """Test dch.py like gbp dch script does: increment debian version - snapshot mode"""
         self.repo.delete_tag("upstream/1.0")
@@ -344,20 +320,18 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertIsNotNone(re.search(snap_mark + header.group(1), lines[2]))
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_increment_debian_version_with_auto_release(self):
         """Test dch.py like gbp dch script does: increment debian version - auto - release"""
         self.repo.delete_tag("upstream/1.0")
-        options = ["--auto",  "--release"]
+        options = ["--auto", "--release"]
         lines = self.run_dch(options)
         self.assertEqual("test-package (%s) %s; urgency=%s\n" % (new_version_0_9, os_codename, default_urgency), lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
-
     def test_dch_main_increment_debian_version_with_auto_snapshot(self):
         """Test dch.py like gbp dch script does: increment debian version - auto - snapshot mode"""
         self.repo.delete_tag("upstream/1.0")
-        options = ["--auto",  "--snapshot"]
+        options = ["--auto", "--snapshot"]
         lines = self.run_dch(options)
         header = re.search(snap_header_0_9, lines[0])
         self.assertIsNotNone(header)
@@ -365,6 +339,21 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertIsNotNone(re.search(snap_mark + header.group(1), lines[2]))
         self.assertIn("""  * added debian/control\n""", lines)
 
+    def test_dch_main_unreleased_debian_version_with_snapshot(self):
+        """Test dch.py like gbp dch script does: snapshot mode with unreleased debian version"""
+        new_version_1_0 = '1.0-1'
+        options = ["--commit"]
+        options.append("--commit-msg=UNRELEASED-version")
+        lines = self.run_dch()
+        header = re.search(r"\(%s\) UNRELEASED" % new_version_1_0, lines[0])
+        self.assertIsNotNone(header)
+        options = ["--snapshot", "--auto"]
+        lines = self.run_dch(options)
+        header = re.search(snap_header_1, lines[0])
+        self.assertIsNotNone(header)
+        self.assertEqual(header.lastindex, 1)
+        self.assertIsNotNone(re.search(snap_mark + header.group(1), lines[2]))
+        self.assertIn("""  * added debian/control\n""", lines)
 
     def test_dch_main_closes_default(self):
         options = ["--meta"]
@@ -374,7 +363,6 @@ class TestScriptDch(DebianGitTestRepo):
         self.assertIn("""  * test debian closes commit (Closes: #123456)\n""",
                       lines)
 
-
     def test_dch_main_closes_non_debian_bug_numbers(self):
         self.add_file("closes", "test file",
                       msg="""test non-debian closes 1\n\nCloses: EX-123""")
